//
// MACHINA BOARD: MODERATION PAGES
// --------------------------------------------------


.card.postmoderationlist {
  .card-header{
    .moderation-col{
      font-size: 0.9rem;
      text-transform: uppercase;
      color: $gray;
    }
  }

  .card-body {
    .row{
      margin: 0;
      padding-top: 10px;
      padding-bottom: 5px;
      border-bottom: 1px solid $grayLighter;
    }

    .post-name{
      .post-created{
        font-size: 11px;
        color: #666;
      }
    }

    .topic-name, .forum-name {
      font-size: 0.9rem;
      line-height: 1rem;
    }
  }
}
