# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-05-05 02:08
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('forum', '0003_remove_forum_is_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='forum',
            name='direct_posts_count',
            field=models.PositiveIntegerField(blank=True, default=0, editable=False, verbose_name='Direct number of posts'),
        ),
        migrations.AddField(
            model_name='forum',
            name='direct_topics_count',
            field=models.PositiveIntegerField(blank=True, default=0, editable=False, verbose_name='Direct number of topics'),
        ),
    ]
