# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-07 03:02
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('forum_tracking', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='forumreadtrack',
            name='mark_time',
            field=models.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name='topicreadtrack',
            name='mark_time',
            field=models.DateTimeField(auto_now=True, db_index=True),
        ),
    ]
