{% extends 'board_base.html' %}
{% load i18n %}

{% block sub_title %}{% trans "View unread topics" %}{% endblock sub_title %}


{% block content %}
<div class="row"><div class="col-12"><h1>{% trans "View unread topics" %}</h1></div></div>
<div class="row">
  <div class="col-12 col-md-4 topic-actions-block">
    {% if paginator.count > 0 %}
    <p class="text-muted">
      {% blocktrans trimmed count topic_length=paginator.count %}
      {{ topic_length }} unread topic found{% plural %}{{ topic_length }} unread topics found
      {% endblocktrans %}
    </p>
    {% endif %}
  </div>
  <div class="col-12 col-md-8 pagination-block">
  {% with "pagination-sm justify-content-end" as pagination_size %}
  {% include "partials/pagination.html" %}
  {% endwith %}
  </div>
</div>
{% trans "There are no unread topics." as empty_message %}
{% with topic_list_title="Topics" empty_message=empty_message force_all_unread=True %}
{% include "forum_conversation/topic_list.html" %}
{% endwith %}
<div class="row">
  <div class="col-xs-12 col-md-12 pagination-block">
    {% with "pagination-sm" as pagination_size %}
      {% include "partials/pagination.html" %}
    {% endwith %}
  </div>
</div>
{% endblock content %}
