//
// MACHINA DJANGO ADMIN UNIQUE STYLES
// --------------------------------------------------


@charset 'UTF-8';


// Core variables and mixins
@import 'variables';

// Components
$fa-font-path: '../fonts/';
@import '@fortawesome/fontawesome-free-webfonts/scss/fontawesome';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-regular';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-brands';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-solid';

// Unique
@import 'admin_pages/forum_change_list';
@import 'admin_pages/forum_permissions';
