# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2017-05-24 01:36
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('forum', '0005_auto_20170504_2113'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='forum',
            name='posts_count',
        ),
        migrations.RemoveField(
            model_name='forum',
            name='topics_count',
        ),
    ]
