//
// MACHINA BOARD VENDOR STYLES
// --------------------------------------------------


@charset 'UTF-8';
@import 'bootstrap/scss/bootstrap';
$fa-font-path: '../fonts/';
@import '@fortawesome/fontawesome-free-webfonts/scss/fontawesome';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-regular';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-brands';
@import '@fortawesome/fontawesome-free-webfonts/scss/fa-solid';
